from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

LEM = SchLib(tool=SKIDL).add_parts(*[
        Part(name='LEM_HO-NP',dest=TEMPLATE,tool=SKIDL,keywords='current transducer',description='LEM current transducer HO 8-NP-xxxx, 5V supply voltage, Nominal measurement current (Ipn) 8A, Standard option xxxx = 0000: 2.5V reference, 3.5us response time, EEPROM Control=yes, over current detection = 2,9*Ipn',ref_prefix='MT',num_units=1,do_erc=True,aliases=['LEM_HO_8-NP', 'LEM_HO_15-NP', 'LEM_HO_25-NP'],pins=[
            Pin(num='1',name='5V',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='Vout',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='Vref',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='Over_Current',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='6',name='Standby',do_erc=True),
            Pin(num='7',name='N/A(GND)',do_erc=True),
            Pin(num='8',name='L1_1',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='L2_1',func=Pin.PASSIVE,do_erc=True),
            Pin(num='10',name='L3_1',func=Pin.PASSIVE,do_erc=True),
            Pin(num='11',name='L3_2',func=Pin.PASSIVE,do_erc=True),
            Pin(num='12',name='L2_2',func=Pin.PASSIVE,do_erc=True),
            Pin(num='13',name='L1_2',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='LEM_HO-NP_SP33',dest=TEMPLATE,tool=SKIDL,keywords='current transducer',description='LEM current transducer HO 8-NP/SP33-xxxx, 3.3V supply voltage, Nominal measurement current (Ipn) 8A, Standard option xxxx = 1000: 1.65V reference, 3.5us response time, EEPROM Control=yes, over current detection = 2,9*Ipn',ref_prefix='MT',num_units=1,do_erc=True,aliases=['LEM_HO_8-NP_SP33', 'LEM_HO_15-NP_SP33', 'LEM_HO_25-NP_SP33'],pins=[
            Pin(num='1',name='3V3',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='Vout',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='Vref',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='Over_Current',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='6',name='Standby',do_erc=True),
            Pin(num='7',name='N/A(GND)',do_erc=True),
            Pin(num='8',name='L1_1',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='L2_1',func=Pin.PASSIVE,do_erc=True),
            Pin(num='10',name='L3_1',func=Pin.PASSIVE,do_erc=True),
            Pin(num='11',name='L3_2',func=Pin.PASSIVE,do_erc=True),
            Pin(num='12',name='L2_2',func=Pin.PASSIVE,do_erc=True),
            Pin(num='13',name='L1_2',func=Pin.PASSIVE,do_erc=True)])])


import pytest
from skidl import *
from .setup_teardown import *

def test_connect_1():
    vreg = Part('xess.lib',
                '1117',
                footprint='null')
    vreg.value = 'NCV1117'
    gnd = Net('GND')
    vin = Net('Vin')
    vout = Net('Vout')
    gnd += vreg[1]
    vin += vreg[2]
    vout += vreg[3]
    assert vreg.is_connected() == True
    assert len(gnd) == 1
    assert len(vin) == 1
    assert len(vout) == 1


def test_connect_2():
    vreg1 = Part('xess.lib',
                 '1117',
                 footprint='null')
    vreg1.value = 'NCV1117'
    vreg2 = 1 * vreg1
    gnd = Net('GND')
    vin = Net('Vin')
    vout = Net('Vout')
    gnd += vreg1[1]
    vin += vreg1[2]
    vout += vreg1[3]
    vreg2[1, 2, 3] += gnd, vin, vout
    assert vreg1.is_connected() == True
    assert vreg2.is_connected() == True
    assert len(gnd) == 2
    assert len(vin) == 2
    assert len(vout) == 2


def test_connect_3():
    vreg1 = Part('xess.lib',
                 '1117',
                 footprint='null')
    vreg1.value = 'NCV1117'
    vreg2 = 1 * vreg1
    gnd = Net('GND')
    vin = Net('Vin')
    vout = Net('Vout')
    gnd += vreg1[1], vreg2[1]
    vin += vreg1[2], vreg2[2]
    vout += vreg1[3], vreg2[3]
    assert vreg1.is_connected() == True
    assert vreg2.is_connected() == True
    assert len(gnd) == 2
    assert len(vin) == 2
    assert len(vout) == 2


def test_connect_4():
    vreg1 = Part('xess.lib',
                 '1117',
                 footprint='null')
    vreg1.value = 'NCV1117'
    vreg2 = 1 * vreg1
    gnd = Net('GND')
    vin = Net('Vin')
    vout = Net('Vout')
    Bus('TMP', gnd, vin, vout)[:] += vreg1[1:3]
    Bus('TMP', gnd, vin, vout)[1:2] += vreg2[(2, 3)]
    assert vreg1.is_connected() == True
    assert vreg2.is_connected() == True
    assert len(gnd) == 1
    assert len(vin) == 2
    assert len(vout) == 2


def test_connect_5():
    vreg1 = Part('xess.lib',
                 '1117',
                 footprint='null')
    gnd = Net('GND')
    vin = Net('Vin')
    vreg1['GND', 'IN'] += gnd, vin
    vreg1['HS'] += vreg1['OUT']
    vreg1['OUT'] += vreg1['HS']
    assert vreg1.is_connected() == True
    assert len(gnd) == 1
    assert len(vin) == 1
    assert len(vreg1['IN'].net) == 1
    assert len(vreg1['HS'].net) == 2


def test_connect_6():
    gnd = Net('GND')
    vin = Net('Vin')
    vreg1 = Part('xess.lib',
                 '1117',
                 footprint='null',
                 connections={'GND': gnd,
                              'IN': vin})
    vreg2 = Part('xess.lib',
                 '1117',
                 footprint='null',
                 connections={'GND': gnd,
                              'IN': vin})
    vreg1['HS'] += vreg1['OUT']
    vregs = 2 * vreg1
    vregs = vreg1.copy(2)
    assert vreg1.is_connected() == True
    assert len(gnd) == 6
    assert len(vin) == 6
    assert len(vreg1['IN'].net) == 6
    assert len(vreg1['HS'].net) == 10


def test_connect_7():
    n1, n2 = 2 * Net()
    p1, p2, p3 = 3 * Pin()
    p1 += n1
    n2 += p2, p3
    p1 += p2, p3
    assert len(p1.net) == 3
    assert len(p1.net) == len(p2.net) == len(p3.net)
    assert len(n1) == 3
    assert len(n2) == 3
    assert n2.is_attached(n1)



from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

Power_Management = SchLib(tool=SKIDL).add_parts(*[
        Part(name='FAN7842',dest=TEMPLATE,tool=SKIDL,keywords='gate driver',description='High and Low Side Gate Driver',ref_prefix='U',num_units=1,fplist=['SOIC*3.9x4.9mm*Pitch1.27mm*'],do_erc=True,pins=[
            Pin(num='1',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='HIN',do_erc=True),
            Pin(num='3',name='LIN',do_erc=True),
            Pin(num='4',name='COM',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='LO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='VS',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='HO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='VB',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LM5051',dest=TEMPLATE,tool=SKIDL,keywords='negative low-side or-ing ideal-diode',description='Low side OR-ing FET controller, -6V to -100V operation',ref_prefix='U',num_units=1,fplist=['SOIC*Pitch1.27mm*'],do_erc=True,pins=[
            Pin(num='1',name='Line',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='VCC',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='OFF',do_erc=True),
            Pin(num='4',name='~FGD',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='INN',do_erc=True),
            Pin(num='7',name='INP',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='GATE',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='LM5060',dest=TEMPLATE,tool=SKIDL,keywords='high-voltage mosfet-driver hot-swap',description='High side protection controller, +5.5V to +65V operation, VSSOP-10 package',ref_prefix='U',num_units=1,fplist=['*SOP*3x3mm*Pitch0.5mm*'],do_erc=True,pins=[
            Pin(num='6',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='SENSE',do_erc=True),
            Pin(num='2',name='VIN',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='OVP',do_erc=True),
            Pin(num='4',name='UVLO',do_erc=True),
            Pin(num='5',name='EN',do_erc=True),
            Pin(num='7',name='TIMER',do_erc=True),
            Pin(num='8',name='~PGD',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='9',name='OUT',do_erc=True),
            Pin(num='10',name='GATE',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='LT1641-1',dest=TEMPLATE,tool=SKIDL,keywords='power switch FET driver',description='Positive high voltage hot swap controller +10V to +80V with auto-retry operation',ref_prefix='U',num_units=1,fplist=['SOIC*Pitch_1.27mm*'],do_erc=True,aliases=['LT1641-2', 'MIC2587-1', 'MIC2587R-1'],pins=[
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='ON',do_erc=True),
            Pin(num='2',name='FB',do_erc=True),
            Pin(num='3',name='PWRGD',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='5',name='TIMER',do_erc=True),
            Pin(num='6',name='GATE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='Sense',do_erc=True),
            Pin(num='8',name='Vcc',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LTC4007',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='LTC4357DCB',dest=TEMPLATE,tool=SKIDL,keywords='ideal-diode or-ing',description='Ideal diode controller, 9-80V operation, DFN-6 package',ref_prefix='U',num_units=1,fplist=['DFN*1EP*3.2mm*Pitch0.5mm*'],do_erc=True,pins=[
            Pin(num='1',name='OUT',do_erc=True),
            Pin(num='2',name='IN',do_erc=True),
            Pin(num='3',name='GATE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='6',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='PAD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LTC4357MS8',dest=TEMPLATE,tool=SKIDL,keywords='ideal-diode or-ing',description='Ideal diode controller, 9-80V operation, MSOP-8 package',ref_prefix='U',num_units=1,fplist=['MSOP*3x3mm*Pitch0.65mm*'],do_erc=True,pins=[
            Pin(num='1',name='IN',do_erc=True),
            Pin(num='2',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='3',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='4',name='GATE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='7',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='OUT',do_erc=True)]),
        Part(name='LTC4359-DCB',dest=TEMPLATE,tool=SKIDL,keywords='ideal-diode or-ing reverse-protection',description='Ideal diode controller with reverse input protection, DFN-6 package',ref_prefix='U',num_units=1,fplist=['DFN*1EP*3x2mm*Pitch0.65mm*'],do_erc=True,pins=[
            Pin(num='1',name='OUT',do_erc=True),
            Pin(num='2',name='GATE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='SRC',do_erc=True),
            Pin(num='4',name='IN',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='~SHDN',do_erc=True),
            Pin(num='6',name='Vss',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='Pad',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LTC4359-MS8',dest=TEMPLATE,tool=SKIDL,keywords='ideal-diode or-ing reverse-protection',description='Ideal diode controller with reverse input protection, MSOP-8 package',ref_prefix='U',num_units=1,fplist=['MSOP*3x3mm*Pitch0.65mm*'],do_erc=True,pins=[
            Pin(num='1',name='GATE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='SRC',do_erc=True),
            Pin(num='3',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='4',name='IN',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='~SHDN',do_erc=True),
            Pin(num='6',name='Vss',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='8',name='OUT',do_erc=True)]),
        Part(name='LTC4364CDE',dest=TEMPLATE,tool=SKIDL,keywords='surge overvoltage undervoltage reverse-polarity protection diode ORing MOSFET driver',description='Surge stopper with ideal diode, UV and OV protection -40V to +80V in DFN-14 package, -40°C to +85°C',ref_prefix='U',num_units=1,fplist=['DFN*3x4mm*Pitch0.5mm*'],do_erc=True,aliases=['LTC4364IDE', 'LTC4364HDE'],pins=[
            Pin(num='1',name='OUT',do_erc=True),
            Pin(num='2',name='SENSE',do_erc=True),
            Pin(num='3',name='DGATE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='SOURCE',do_erc=True),
            Pin(num='5',name='GATE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='~SHDN',do_erc=True),
            Pin(num='8',name='UV',do_erc=True),
            Pin(num='9',name='OV',do_erc=True),
            Pin(num='10',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='~FLT',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='12',name='ENOUT',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='13',name='TMR',do_erc=True),
            Pin(num='14',name='FB',do_erc=True),
            Pin(num='15',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LTC4364CMS',dest=TEMPLATE,tool=SKIDL,keywords='surge overvoltage undervoltage reverse-polarity protection diode ORing MOSFET driver',description='Surge stopper with ideal diode, UV and OV protection -40V to +80V in MSOP-16 package, -40°C to +85°C',ref_prefix='U',num_units=1,fplist=['MSOP*3x4mm*Pitch0.5mm*'],do_erc=True,aliases=['LTC4364IMS', 'LTC4364HMS'],pins=[
            Pin(num='1',name='OUT',do_erc=True),
            Pin(num='2',name='SENSE',do_erc=True),
            Pin(num='3',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='4',name='DGATE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='SOURCE',do_erc=True),
            Pin(num='6',name='HGATE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='~SHDN',do_erc=True),
            Pin(num='10',name='UV',do_erc=True),
            Pin(num='11',name='OV',do_erc=True),
            Pin(num='12',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='~FLT',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='14',name='ENOUT',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='15',name='TMR',do_erc=True),
            Pin(num='16',name='FB',do_erc=True)]),
        Part(name='LTC4364CS',dest=TEMPLATE,tool=SKIDL,keywords='surge overvoltage undervoltage reverse-polarity protection diode ORing MOSFET driver',description='Surge stopper with ideal diode, UV and OV protection -40V to +80V in SOIC-16 package, -40°C to +85°C',ref_prefix='U',num_units=1,fplist=['SOIC*3.9x9.9mm*Pitch1.27mm*'],do_erc=True,aliases=['LTC4364IS', 'LTC4364HS'],pins=[
            Pin(num='1',name='OUT',do_erc=True),
            Pin(num='2',name='SENSE',do_erc=True),
            Pin(num='3',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='4',name='DGATE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='SOURCE',do_erc=True),
            Pin(num='6',name='HGATE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='~SHDN',do_erc=True),
            Pin(num='10',name='UV',do_erc=True),
            Pin(num='11',name='OV',do_erc=True),
            Pin(num='12',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='~FLT',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='14',name='ENOUT',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='15',name='TMR',do_erc=True),
            Pin(num='16',name='FB',do_erc=True)]),
        Part(name='LTC4365DDB',dest=TEMPLATE,tool=SKIDL,keywords='overvoltage undervoltage reverse-polarity protection',description='Overvoltage, Undervoltage and Reverse Supply Protection Controller, 3x2mm DFN-8 package, 1ms fault recovery',ref_prefix='U',num_units=1,fplist=['DFN*1EP*2x3mm*Pitch0.5mm*'],do_erc=True,aliases=['LTC4365DDB-1'],pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='OV',do_erc=True),
            Pin(num='3',name='UV',do_erc=True),
            Pin(num='4',name='Vin',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='GATE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='Vout',do_erc=True),
            Pin(num='7',name='~FAULT',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='8',name='~SHDN',do_erc=True),
            Pin(num='9',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LTC4365TS8',dest=TEMPLATE,tool=SKIDL,keywords='overvoltage undervoltage reverse-polarity protection',description='Overvoltage, Undervoltage and Reverse Supply Protection Controller, TSOT23-8 package, 1ms fault recovery',ref_prefix='U',num_units=1,fplist=['*SOT-23*'],do_erc=True,aliases=['LTC4365TS8-1'],pins=[
            Pin(num='1',name='Vin',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='UV',do_erc=True),
            Pin(num='3',name='OV',do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='~SHDN',do_erc=True),
            Pin(num='6',name='~FAULT',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='7',name='Vout',do_erc=True),
            Pin(num='8',name='GATE',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='LTC4417CGN',dest=TEMPLATE,tool=SKIDL,keywords='switch power FET sequence',description='Prioritized PowerPath controller QFN-24, industrial temperature range',ref_prefix='U',num_units=1,fplist=['QFN*4x4mm*Pitch0.5mm*'],do_erc=True,aliases=['LTC4417IGN', 'LTC4417HGN'],pins=[
            Pin(num='1',name='UV1',do_erc=True),
            Pin(num='2',name='OV1',do_erc=True),
            Pin(num='3',name='UV2',do_erc=True),
            Pin(num='4',name='OV2',do_erc=True),
            Pin(num='5',name='UV3',do_erc=True),
            Pin(num='6',name='OV3',do_erc=True),
            Pin(num='7',name='~VALID1',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='8',name='~VALID2',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='9',name='~VALID3',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='10',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='V2',do_erc=True),
            Pin(num='11',name='CAS',func=Pin.OUTPUT,do_erc=True),
            Pin(num='21',name='V1',do_erc=True),
            Pin(num='12',name='VOUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='22',name='EN',do_erc=True),
            Pin(num='13',name='G3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='23',name='~SHDN',do_erc=True),
            Pin(num='14',name='VS3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='24',name='HYS',do_erc=True),
            Pin(num='15',name='G2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='25',name='PAD',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VS2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='17',name='G1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='18',name='VS1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='19',name='V3',do_erc=True)]),
        Part(name='LTC4440EMS8',dest=TEMPLATE,tool=SKIDL,keywords='high-side mosfet-driver',description='High-side, N-Channel, Mosfet driver, 80V input, -40°C to +125°C, MSOP-8 package',ref_prefix='U',num_units=1,fplist=['MSOP*1EP*3x3mm*Pitch0.65mm*'],do_erc=True,aliases=['LTC4440IMS8'],pins=[
            Pin(num='1',name='INP',do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='6',name='BOOST',do_erc=True),
            Pin(num='7',name='TG',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='TS',do_erc=True),
            Pin(num='9',name='PAD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LTC4440ES6',dest=TEMPLATE,tool=SKIDL,keywords='high-side mosfet-driver',description='High-side, N-Channel, Mosfet driver, 80V input, -40°C to +85°C, SOT23-6 package',ref_prefix='U',num_units=1,fplist=['SOT-23*'],do_erc=True,aliases=['LTC4440IS6'],pins=[
            Pin(num='1',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='INP',do_erc=True),
            Pin(num='4',name='TS',do_erc=True),
            Pin(num='5',name='TG',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='BOOST',do_erc=True)]),
        Part(name='MC33064D',dest=TEMPLATE,tool=SKIDL,do_erc=True,aliases=['MC34064D']),
        Part(name='MC34064P',dest=TEMPLATE,tool=SKIDL,do_erc=True,aliases=['MC33064P']),
        Part(name='MCP100-270D',dest=TEMPLATE,tool=SKIDL,keywords='supervisor reset push-pull',description='Microcontroller reset monitor, 4.85V threshold, active low output',ref_prefix='U',num_units=1,fplist=['SOT-23*', 'TO-92*'],do_erc=True,aliases=['MCP100-300D', 'MCP100-315D', 'MCP100-450D', 'MCP100-460D', 'MCP100-475D', 'MCP100-485D'],pins=[
            Pin(num='1',name='~RST',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='MCP101-270D',dest=TEMPLATE,tool=SKIDL,keywords='supervisor reset push-pull',description='Microcontroller reset monitor, 4.85V threshold, active high output',ref_prefix='U',num_units=1,fplist=['SOT-23*', 'TO-92*'],do_erc=True,aliases=['MCP101-300D', 'MCP101-315D', 'MCP101-450D', 'MCP101-460D', 'MCP101-475D', 'MCP101-485D'],pins=[
            Pin(num='1',name='RST',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='MCP1415',dest=TEMPLATE,tool=SKIDL,keywords='mosfet gate driver',description='1.5A High speed power MOSFET driver with inverting output',ref_prefix='U',num_units=1,fplist=['SOT-23*'],do_erc=True,pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='IN',do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='~OUT',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='MCP1415R',dest=TEMPLATE,tool=SKIDL,keywords='mosfet gate driver',description='1.5A High speed power MOSFET driver with inverting output',ref_prefix='U',num_units=1,fplist=['SOT-23*'],do_erc=True,pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='IN',do_erc=True),
            Pin(num='4',name='~OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='Vdd',func=Pin.PWRIN,do_erc=True)]),
        Part(name='MCP1416',dest=TEMPLATE,tool=SKIDL,keywords='mosfet gate driver',description='1.5A High speed power MOSFET driver with non-inverting output',ref_prefix='U',num_units=1,fplist=['SOT-23*'],do_erc=True,pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='IN',do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='OUT',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='MCP1416R',dest=TEMPLATE,tool=SKIDL,keywords='mosfet gate driver',description='1.5A High speed power MOSFET driver with non-inverting output',ref_prefix='U',num_units=1,fplist=['SOT-23*'],do_erc=True,pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='IN',do_erc=True),
            Pin(num='4',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='Vdd',func=Pin.PWRIN,do_erc=True)]),
        Part(name='MIC2026-1BN',dest=TEMPLATE,tool=SKIDL,keywords='mosfet distribution',description='Dual-channel, high side, power distribution switch, 2.7V-5.5V, Active Low Output, in DIP-8 Package',ref_prefix='U',num_units=1,fplist=['SOIC*', 'DIP*'],do_erc=True,aliases=['MIC2026-1BM', 'MIC2026-2BN', 'MIC2026-2BM'],pins=[
            Pin(num='1',name='ENA',do_erc=True),
            Pin(num='2',name='FLGA',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='FLGB',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='ENB',do_erc=True),
            Pin(num='5',name='OUTB',func=Pin.PWROUT,do_erc=True),
            Pin(num='6',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='IN',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='OUTA',func=Pin.PWROUT,do_erc=True)]),
        Part(name='RT9701',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='TCM809',dest=TEMPLATE,tool=SKIDL,keywords='supervisor reset push-pull',description='Microcontroller reset monitor, active low output',ref_prefix='U',num_units=1,fplist=['SOT-23*', 'SC-70*'],do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='~RESET~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='TCM810',dest=TEMPLATE,tool=SKIDL,keywords='supervisor reset push-pull',description='Microcontroller reset monitor, active high output',ref_prefix='U',num_units=1,fplist=['SOT-23*', 'SC-70*'],do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='RESET',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='TL7702',dest=TEMPLATE,tool=SKIDL,do_erc=True,aliases=['TL7705'])])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

my_lt1083 = SchLib(tool=SKIDL).add_parts(*[
        Part(name='LT1083-12',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1083-5',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1083',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1084-12',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1084-3.3',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1084-5',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1084',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1085-12',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1085-3.3',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1085-3.6',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1085-5',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1085',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1086-12',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1086-2.85',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1086-3.3',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1086-3.6',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1086-5',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1086',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1086H',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)])])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

display = SchLib(tool=SKIDL).add_parts(*[
        Part(name='7SEGM',dest=TEMPLATE,tool=SKIDL,keywords='DEV',description='Afficheur Leds 7 segments',ref_prefix='S',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='Segm_E',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='Segm_D',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='Segm_C',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='SegmDP',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='Segm_B',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='Segm_A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='8',name='K',do_erc=True),
            Pin(num='9',name='Segm_F',func=Pin.PASSIVE,do_erc=True),
            Pin(num='10',name='Segm_G',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='7SEGMENTS',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='AG12864E',dest=TEMPLATE,tool=SKIDL,keywords='LCD Graphics 128x64 KS108 Ampire',description='Graphics Display 128x64px, 1/64 Duty, KS108B Controller, AMPIRE',ref_prefix='DS',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='VO',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='DB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='DB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='DB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='DB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='DB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='DB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='DB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='LEDK',func=Pin.PASSIVE,do_erc=True),
            Pin(num='11',name='DB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='~CS1~',do_erc=True),
            Pin(num='13',name='~CS2~',do_erc=True),
            Pin(num='14',name='~RST~',do_erc=True),
            Pin(num='15',name='R/~W~',do_erc=True),
            Pin(num='16',name='~C~/D',do_erc=True),
            Pin(num='17',name='EN',do_erc=True),
            Pin(num='18',name='VEE',func=Pin.PASSIVE,do_erc=True),
            Pin(num='19',name='LEDA',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='CA56-12',dest=TEMPLATE,tool=SKIDL,keywords='7 SEGMENTS 4 display',description='Kingbright 4 x 7-segment common anode display',ref_prefix='AFF',num_units=1,fplist=['Cx56-12'],do_erc=True,pins=[
            Pin(num='1',name='e',do_erc=True),
            Pin(num='2',name='d',do_erc=True),
            Pin(num='3',name='DP',do_erc=True),
            Pin(num='4',name='c',do_erc=True),
            Pin(num='5',name='g',do_erc=True),
            Pin(num='6',name='CA4',do_erc=True),
            Pin(num='7',name='b',do_erc=True),
            Pin(num='8',name='CA3',do_erc=True),
            Pin(num='9',name='CA2',do_erc=True),
            Pin(num='10',name='f',do_erc=True),
            Pin(num='11',name='a',do_erc=True),
            Pin(num='12',name='CA1',do_erc=True)]),
        Part(name='CC56-12',dest=TEMPLATE,tool=SKIDL,keywords='7 SEGMENTS 4 display',description='Kingbright 4 x 7-segment common cathode display',ref_prefix='AFF',num_units=1,fplist=['Cx56-12'],do_erc=True,pins=[
            Pin(num='1',name='e',do_erc=True),
            Pin(num='2',name='d',do_erc=True),
            Pin(num='3',name='DP',do_erc=True),
            Pin(num='4',name='c',do_erc=True),
            Pin(num='5',name='g',do_erc=True),
            Pin(num='6',name='CC4',do_erc=True),
            Pin(num='7',name='b',do_erc=True),
            Pin(num='8',name='CC3',do_erc=True),
            Pin(num='9',name='CC2',do_erc=True),
            Pin(num='10',name='f',do_erc=True),
            Pin(num='11',name='a',do_erc=True),
            Pin(num='12',name='CC1',do_erc=True)]),
        Part(name='DA04-11',dest=TEMPLATE,tool=SKIDL,keywords='7 SEGMENTS',description='2 x 7 Segments common A.',ref_prefix='AFF',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='c',do_erc=True),
            Pin(num='2',name='e',do_erc=True),
            Pin(num='3',name='d',do_erc=True),
            Pin(num='4',name='Anod1',do_erc=True),
            Pin(num='5',name='Anod2',do_erc=True),
            Pin(num='6',name='d',do_erc=True),
            Pin(num='7',name='e',do_erc=True),
            Pin(num='8',name='c',do_erc=True),
            Pin(num='9',name='g',do_erc=True),
            Pin(num='10',name='a',do_erc=True),
            Pin(num='11',name='f',do_erc=True),
            Pin(num='12',name='b',do_erc=True),
            Pin(num='13',name='b',do_erc=True),
            Pin(num='14',name='f',do_erc=True),
            Pin(num='15',name='a',do_erc=True),
            Pin(num='16',name='g',do_erc=True)]),
        Part(name='DC04-11',dest=TEMPLATE,tool=SKIDL,keywords='7 SEGMENTS',description='2 x 7 Segments common K.',ref_prefix='AFF',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='c',do_erc=True),
            Pin(num='2',name='e',do_erc=True),
            Pin(num='3',name='d',do_erc=True),
            Pin(num='4',name='D1',do_erc=True),
            Pin(num='5',name='D2',do_erc=True),
            Pin(num='6',name='d',do_erc=True),
            Pin(num='7',name='e',do_erc=True),
            Pin(num='8',name='c',do_erc=True),
            Pin(num='9',name='g',do_erc=True),
            Pin(num='10',name='a',do_erc=True),
            Pin(num='11',name='f',do_erc=True),
            Pin(num='12',name='b',do_erc=True),
            Pin(num='13',name='b',do_erc=True),
            Pin(num='14',name='f',do_erc=True),
            Pin(num='15',name='a',do_erc=True),
            Pin(num='16',name='g',do_erc=True)]),
        Part(name='DISPLAY',dest=TEMPLATE,tool=SKIDL,keywords='DEV',description='Afficheur LCD nLignes',ref_prefix='S',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='VLCD',do_erc=True),
            Pin(num='4',name='RS',do_erc=True),
            Pin(num='5',name='R/W',do_erc=True),
            Pin(num='6',name='CS',do_erc=True),
            Pin(num='7',name='D0',func=Pin.TRISTATE,do_erc=True),
            Pin(num='8',name='D1',func=Pin.TRISTATE,do_erc=True),
            Pin(num='9',name='D2',func=Pin.TRISTATE,do_erc=True),
            Pin(num='10',name='D3',func=Pin.TRISTATE,do_erc=True),
            Pin(num='11',name='D4',func=Pin.TRISTATE,do_erc=True),
            Pin(num='12',name='D5',func=Pin.TRISTATE,do_erc=True),
            Pin(num='13',name='D6',func=Pin.TRISTATE,do_erc=True),
            Pin(num='14',name='D7',func=Pin.TRISTATE,do_erc=True)]),
        Part(name='DISPLAY_3_LIGNE',dest=TEMPLATE,tool=SKIDL,description='DISPLAY EA7123-12C',ref_prefix='S',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='VLCD',do_erc=True),
            Pin(num='4',name='VO',do_erc=True),
            Pin(num='5',name='SDA',do_erc=True),
            Pin(num='6',name='SCL',do_erc=True)]),
        Part(name='DOT-BAR',dest=TEMPLATE,tool=SKIDL,keywords='BAR DOT',description='GRAPH unit',ref_prefix='BAR',num_units=10,do_erc=True,pins=[
            Pin(num='1',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='20',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='19',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='18',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='17',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='16',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='15',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='14',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='8',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='13',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='12',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='10',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='11',name='K',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='DOT-BAR2',dest=TEMPLATE,tool=SKIDL,keywords='BAR DOT',description='BAR GRAPH Block',ref_prefix='BAR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='A',do_erc=True),
            Pin(num='8',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='10',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='20',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='11',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='12',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='13',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='14',name='K',do_erc=True),
            Pin(num='15',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='16',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='17',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='18',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='19',name='K',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='ELD-426x',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='HCLD0438',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='HDSP-7xxx-A',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='HDSP-7xxx-B',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='HDSP-7xxx-C',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='HDSP-7xxx-D',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='HY1602E',dest=TEMPLATE,tool=SKIDL,keywords='LCD 16x2 Alphanumeric 16pin Blue/Yellow/Green Backlight',description='HY1602E',ref_prefix='DS',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='LEDK',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='LEDA',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='Vo',do_erc=True),
            Pin(num='6',name='RS',do_erc=True),
            Pin(num='7',name='R/~W',do_erc=True),
            Pin(num='8',name='E',do_erc=True),
            Pin(num='9',name='DB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='DB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='DB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='DB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='DB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='DB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='DB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='DB7',func=Pin.BIDIR,do_erc=True)]),
        Part(name='ILI9341_LCD_Breakout',dest=TEMPLATE,tool=SKIDL,keywords='GLCD TFT ILI9341 320x240',description='ILI9341 controller, SPI TFT LCD Display, 9-pin breakout PCB, 4-pin SD card interface, 5V/3.3V',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='Vcc',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='~CS',do_erc=True),
            Pin(num='4',name='Reset',do_erc=True),
            Pin(num='5',name='D/~C',do_erc=True),
            Pin(num='6',name='MOSI',do_erc=True),
            Pin(num='7',name='SCK',do_erc=True),
            Pin(num='8',name='LED',do_erc=True),
            Pin(num='9',name='MISO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='10',name='SD_CS',do_erc=True),
            Pin(num='11',name='SD_MOSI',do_erc=True),
            Pin(num='12',name='SD_MISO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='SD_SCK',do_erc=True)]),
        Part(name='LCD16X2',dest=TEMPLATE,tool=SKIDL,keywords='Generic LCD 16x2 Alphanumeric 16pin Green Backlight',description='WC1602A0-SFYLYNC06',ref_prefix='DS',num_units=1,do_erc=True,aliases=['LCD-016N002L'],pins=[
            Pin(num='1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='VO',do_erc=True),
            Pin(num='4',name='RS',do_erc=True),
            Pin(num='5',name='R/W',do_erc=True),
            Pin(num='6',name='E',do_erc=True),
            Pin(num='7',name='D0',do_erc=True),
            Pin(num='8',name='D1',do_erc=True),
            Pin(num='9',name='D2',do_erc=True),
            Pin(num='10',name='D3',do_erc=True),
            Pin(num='11',name='D4',do_erc=True),
            Pin(num='12',name='D5',do_erc=True),
            Pin(num='13',name='D6',do_erc=True),
            Pin(num='14',name='D7',do_erc=True),
            Pin(num='15',name='LED+',func=Pin.PASSIVE,do_erc=True),
            Pin(num='16',name='LED-',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='LCD4',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='LM16255K',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='LTS-6960HR',dest=TEMPLATE,tool=SKIDL,keywords='7 SEGMENTS',description='DISPLAY 7 SEGMENTS common A.',ref_prefix='AFF',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='e',do_erc=True),
            Pin(num='2',name='d',do_erc=True),
            Pin(num='3',name='C.A.',do_erc=True),
            Pin(num='4',name='c',do_erc=True),
            Pin(num='5',name='DP',do_erc=True),
            Pin(num='6',name='b',do_erc=True),
            Pin(num='7',name='a',do_erc=True),
            Pin(num='8',name='C.A.',do_erc=True),
            Pin(num='9',name='f',do_erc=True),
            Pin(num='10',name='g',do_erc=True)]),
        Part(name='LTS-6980HR',dest=TEMPLATE,tool=SKIDL,keywords='7 SEGMENTS',description='DISPLAY 7 SEGMENTS common K',ref_prefix='AFF',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='e',do_erc=True),
            Pin(num='2',name='d',do_erc=True),
            Pin(num='3',name='C.K.',do_erc=True),
            Pin(num='4',name='c',do_erc=True),
            Pin(num='5',name='DP',do_erc=True),
            Pin(num='6',name='b',do_erc=True),
            Pin(num='7',name='a',do_erc=True),
            Pin(num='8',name='C.K.',do_erc=True),
            Pin(num='9',name='f',do_erc=True),
            Pin(num='10',name='g',do_erc=True)]),
        Part(name='MAN3640A',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='MAN71A',dest=TEMPLATE,tool=SKIDL,keywords='DISPLAY LED',description='7 segments display - Common anods',ref_prefix='AFF',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='a',do_erc=True),
            Pin(num='2',name='f',do_erc=True),
            Pin(num='3',name='C.A.',do_erc=True),
            Pin(num='7',name='e',do_erc=True),
            Pin(num='8',name='d',do_erc=True),
            Pin(num='9',name='DP',do_erc=True),
            Pin(num='10',name='c',do_erc=True),
            Pin(num='11',name='g',do_erc=True),
            Pin(num='13',name='b',do_erc=True),
            Pin(num='14',name='C.A.',do_erc=True)]),
        Part(name='RC1602A-GHW-ESX',dest=TEMPLATE,tool=SKIDL,keywords='LCD 16x2 Alphanumeric 16pin Gray Backlight',description='RC1602A-GHW-ESX',ref_prefix='DS',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='Vo',do_erc=True),
            Pin(num='4',name='RS',do_erc=True),
            Pin(num='5',name='R/~W',do_erc=True),
            Pin(num='6',name='E',do_erc=True),
            Pin(num='7',name='DB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='DB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='DB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='DB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='DB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='DB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='DB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='DB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='LED+',func=Pin.PASSIVE,do_erc=True),
            Pin(num='16',name='LED-',func=Pin.PASSIVE,do_erc=True)])])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

gennum = SchLib(tool=SKIDL).add_parts(*[
        Part(name='GS2962',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='GS4910B',dest=TEMPLATE,tool=SKIDL,do_erc=True,aliases=['GS4911B']),
        Part(name='GS9020',dest=TEMPLATE,tool=SKIDL,ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='VDD',do_erc=True),
            Pin(num='2',name='GND',do_erc=True),
            Pin(num='3',name='GND',do_erc=True),
            Pin(num='4',name='VDD',do_erc=True),
            Pin(num='5',name='VDD_SDI',do_erc=True),
            Pin(num='6',name='SDI',do_erc=True),
            Pin(num='7',name='SDI',do_erc=True),
            Pin(num='8',name='VDD_SDI',do_erc=True),
            Pin(num='9',name='VDD_SCI',do_erc=True),
            Pin(num='10',name='SCI',do_erc=True),
            Pin(num='20',name='P5',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='GND',do_erc=True),
            Pin(num='40',name='FL0',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='GND',do_erc=True),
            Pin(num='60',name='DOUT9',func=Pin.OUTPUT,do_erc=True),
            Pin(num='70',name='SDO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='80',name='ANC_DATA',func=Pin.OUTPUT,do_erc=True),
            Pin(num='11',name='SCI',do_erc=True),
            Pin(num='21',name='SCL/P4',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='RESET',do_erc=True),
            Pin(num='41',name='S1',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='VDD',do_erc=True),
            Pin(num='61',name='V',func=Pin.OUTPUT,do_erc=True),
            Pin(num='71',name='SDO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='VDD_SCI',do_erc=True),
            Pin(num='22',name='SDA/P3',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='STD3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='42',name='S0',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='DOUT1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='62',name='H',func=Pin.OUTPUT,do_erc=True),
            Pin(num='72',name='SGND',do_erc=True),
            Pin(num='13',name='VDD',do_erc=True),
            Pin(num='23',name='A2/P2',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='STD2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='43',name='F_R/W',do_erc=True),
            Pin(num='53',name='DOUT2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='63',name='F0',func=Pin.OUTPUT,do_erc=True),
            Pin(num='73',name='VBLANKS/L',do_erc=True),
            Pin(num='14',name='GND',do_erc=True),
            Pin(num='24',name='A1/P1',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='STD1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='44',name='INTERRUPT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='54',name='DOUT3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='64',name='F1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='74',name='BYPASS_EDH',do_erc=True),
            Pin(num='15',name='HOSTIF_MODE',do_erc=True),
            Pin(num='25',name='A0/P0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='STD0',func=Pin.OUTPUT,do_erc=True),
            Pin(num='45',name='FLYWDIS',do_erc=True),
            Pin(num='55',name='DOUT4',func=Pin.OUTPUT,do_erc=True),
            Pin(num='65',name='F2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='75',name='SDOMODE',do_erc=True),
            Pin(num='16',name='FIFOE/S',do_erc=True),
            Pin(num='26',name='R/W',do_erc=True),
            Pin(num='36',name='FL4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='NO_EDH',func=Pin.OUTPUT,do_erc=True),
            Pin(num='56',name='DOUT5',func=Pin.OUTPUT,do_erc=True),
            Pin(num='66',name='FLAG_MAP',do_erc=True),
            Pin(num='76',name='BLANK_EN',do_erc=True),
            Pin(num='17',name='CRC_MODE',do_erc=True),
            Pin(num='27',name='A/D',do_erc=True),
            Pin(num='37',name='FL3',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='FIFO_RESET',func=Pin.OUTPUT,do_erc=True),
            Pin(num='57',name='DOUT6',func=Pin.OUTPUT,do_erc=True),
            Pin(num='67',name='GND',do_erc=True),
            Pin(num='77',name='ANC_CHKSM',do_erc=True),
            Pin(num='18',name='P7',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='CS',do_erc=True),
            Pin(num='38',name='FL2',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='PCLKOUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='58',name='DOUT7',func=Pin.OUTPUT,do_erc=True),
            Pin(num='68',name='VDD',do_erc=True),
            Pin(num='78',name='CLIP_TRS',do_erc=True),
            Pin(num='19',name='P6',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='VDD',do_erc=True),
            Pin(num='39',name='FL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='DOUT0',func=Pin.OUTPUT,do_erc=True),
            Pin(num='59',name='DOUT8',func=Pin.OUTPUT,do_erc=True),
            Pin(num='69',name='SVDD',do_erc=True),
            Pin(num='79',name='TRS_ERR',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='GS9025',dest=TEMPLATE,tool=SKIDL,ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='DDI',do_erc=True),
            Pin(num='2',name='DDI',do_erc=True),
            Pin(num='3',name='VCC_75',do_erc=True),
            Pin(num='4',name='VCC',do_erc=True),
            Pin(num='5',name='VEE',do_erc=True),
            Pin(num='6',name='SDI',do_erc=True),
            Pin(num='7',name='SDI',do_erc=True),
            Pin(num='8',name='VCC',do_erc=True),
            Pin(num='9',name='VEE',do_erc=True),
            Pin(num='10',name='CD_ADJ',do_erc=True),
            Pin(num='20',name='RVCO',do_erc=True),
            Pin(num='30',name='VEE',do_erc=True),
            Pin(num='40',name='SSI/CD',func=Pin.OUTPUT,do_erc=True),
            Pin(num='11',name='AGC-',do_erc=True),
            Pin(num='21',name='CBG',do_erc=True),
            Pin(num='31',name='SDO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='41',name='A/D',do_erc=True),
            Pin(num='12',name='AGC+',do_erc=True),
            Pin(num='22',name='VCC',do_erc=True),
            Pin(num='32',name='SDO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='42',name='SMPTE',do_erc=True),
            Pin(num='13',name='VCC',do_erc=True),
            Pin(num='23',name='SS2',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='VEE',do_erc=True),
            Pin(num='43',name='OEM',func=Pin.OUTPUT,do_erc=True),
            Pin(num='14',name='VEE',do_erc=True),
            Pin(num='24',name='SS1',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='VEE',do_erc=True),
            Pin(num='44',name='VCC_75',do_erc=True),
            Pin(num='15',name='LF+',do_erc=True),
            Pin(num='25',name='SS0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='VCC',do_erc=True),
            Pin(num='16',name='LFS',do_erc=True),
            Pin(num='26',name='AUTO/MAN',do_erc=True),
            Pin(num='36',name='CLK_EN',do_erc=True),
            Pin(num='17',name='LF-',do_erc=True),
            Pin(num='27',name='VEE',do_erc=True),
            Pin(num='37',name='VEE',do_erc=True),
            Pin(num='18',name='VEE',do_erc=True),
            Pin(num='28',name='SCO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='38',name='COSC',do_erc=True),
            Pin(num='19',name='RVCO_RTN',do_erc=True),
            Pin(num='29',name='SCO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='39',name='LOCK',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='GS9032',dest=TEMPLATE,tool=SKIDL,ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='PD9',do_erc=True),
            Pin(num='2',name='PD8',do_erc=True),
            Pin(num='3',name='PD7',do_erc=True),
            Pin(num='4',name='PD6',do_erc=True),
            Pin(num='5',name='PD5',do_erc=True),
            Pin(num='6',name='PD4',do_erc=True),
            Pin(num='7',name='PD3',do_erc=True),
            Pin(num='8',name='PD2',do_erc=True),
            Pin(num='9',name='PD1',do_erc=True),
            Pin(num='10',name='PD0',do_erc=True),
            Pin(num='20',name='LOCK_DET',func=Pin.OUTPUT,do_erc=True),
            Pin(num='30',name='R_SET1',do_erc=True),
            Pin(num='40',name='LBWC',do_erc=True),
            Pin(num='11',name='PCLKIN',do_erc=True),
            Pin(num='21',name='SS0',do_erc=True),
            Pin(num='31',name='BYPASS',do_erc=True),
            Pin(num='41',name='LF+',do_erc=True),
            Pin(num='12',name='VEE3',do_erc=True),
            Pin(num='22',name='R_SET0',do_erc=True),
            Pin(num='32',name='AUTO/MAN',do_erc=True),
            Pin(num='42',name='LF-',do_erc=True),
            Pin(num='13',name='VCC3',do_erc=True),
            Pin(num='23',name='VEE',do_erc=True),
            Pin(num='33',name='RESET',do_erc=True),
            Pin(num='43',name='VEE',do_erc=True),
            Pin(num='14',name='C_OSC',do_erc=True),
            Pin(num='24',name='SDO0',func=Pin.OUTPUT,do_erc=True),
            Pin(num='34',name='VCC1',do_erc=True),
            Pin(num='44',name='SYNC_DIS',do_erc=True),
            Pin(num='15',name='SS2',do_erc=True),
            Pin(num='25',name='SDO0',func=Pin.OUTPUT,do_erc=True),
            Pin(num='35',name='VEE1',do_erc=True),
            Pin(num='16',name='SS1',do_erc=True),
            Pin(num='26',name='VEE',do_erc=True),
            Pin(num='36',name='R_VCO+',do_erc=True),
            Pin(num='17',name='VCC2',do_erc=True),
            Pin(num='27',name='SDO1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='37',name='C_BG',do_erc=True),
            Pin(num='18',name='VEE2',do_erc=True),
            Pin(num='28',name='SDO1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='38',name='R_VCO-',do_erc=True),
            Pin(num='19',name='SDO1_ENABLE',do_erc=True),
            Pin(num='29',name='VEE',do_erc=True),
            Pin(num='39',name='VEE',do_erc=True)])])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

video = SchLib(tool=SKIDL).add_parts(*[
        Part(name='AD725',dest=TEMPLATE,tool=SKIDL,keywords='Video',description='Low Cost RGB to NTSC/PAL Encoder with Luma Trap Port',ref_prefix='U',num_units=1,fplist=['SOIC*7.5x10.3mm*Pitch1.27mm*'],do_erc=True,pins=[
            Pin(num='1',name='NTSC/PAL',do_erc=True),
            Pin(num='2',name='AGND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='4FSC_CLK',do_erc=True),
            Pin(num='4',name='AVCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='CE',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='RED',do_erc=True),
            Pin(num='7',name='GREEN',do_erc=True),
            Pin(num='8',name='BLUE',do_erc=True),
            Pin(num='9',name='CHROM_OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='10',name='CVBS_OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='11',name='LUM_OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='TRAP',do_erc=True),
            Pin(num='13',name='DGND',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='DVCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='15',name='VSYNC',do_erc=True),
            Pin(num='16',name='HSYNC',do_erc=True)]),
        Part(name='AD9891',dest=TEMPLATE,tool=SKIDL,keywords='CCD Signal Processor',description='CCD Signal Processor, 20MHz 10bits, CSPBGA-64',ref_prefix='U',num_units=1,fplist=['BGA*10x10*9.0x9.0mm*Pitch0.8mm*'],do_erc=True,pins=[
            Pin(num='A1',name='VD',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='HD',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='SYNC',do_erc=True),
            Pin(num='D1',name='DCLK',func=Pin.OUTPUT,do_erc=True),
            Pin(num='F1',name='D1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='G1',name='D3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='H1',name='D5',func=Pin.OUTPUT,do_erc=True),
            Pin(num='J1',name='D7',func=Pin.OUTPUT,do_erc=True),
            Pin(num='K1',name='D9',do_erc=True),
            Pin(num='A2',name='DVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='B2',name='DVSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='LD/FD',func=Pin.OUTPUT,do_erc=True),
            Pin(num='D2',name='PBLK/CLPOB',func=Pin.OUTPUT,do_erc=True),
            Pin(num='F2',name='D0/SD0',func=Pin.OUTPUT,do_erc=True),
            Pin(num='G2',name='D2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='H2',name='D4',func=Pin.OUTPUT,do_erc=True),
            Pin(num='J2',name='D6',func=Pin.OUTPUT,do_erc=True),
            Pin(num='K2',name='D8',func=Pin.OUTPUT,do_erc=True),
            Pin(num='A3',name='MSHUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='B3',name='STROBE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='J3',name='VSUB',func=Pin.OUTPUT,do_erc=True),
            Pin(num='K3',name='DRVDD',func=Pin.PWROUT,do_erc=True),
            Pin(num='A4',name='SDI',do_erc=True),
            Pin(num='B4',name='SCK',do_erc=True),
            Pin(num='J4',name='SUBCK',func=Pin.OUTPUT,do_erc=True),
            Pin(num='K4',name='DRVSS',func=Pin.PWROUT,do_erc=True),
            Pin(num='A5',name='REFT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='B5',name='SL',do_erc=True),
            Pin(num='J5',name='V2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='K5',name='V1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='A6',name='REFB',func=Pin.OUTPUT,do_erc=True),
            Pin(num='B6',name='AVSS2',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='V4',func=Pin.OUTPUT,do_erc=True),
            Pin(num='K6',name='V3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='A7',name='BYP3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='B7',name='AVDD2',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VSG2/V6',func=Pin.OUTPUT,do_erc=True),
            Pin(num='K7',name='VSG1/V5',func=Pin.OUTPUT,do_erc=True),
            Pin(num='A8',name='CDD-IN',do_erc=True),
            Pin(num='B8',name='BYP2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='J8',name='VSG4/V8',func=Pin.OUTPUT,do_erc=True),
            Pin(num='K8',name='VSG3/V7',func=Pin.OUTPUT,do_erc=True),
            Pin(num='A9',name='BYP1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='B9',name='AVSS1',func=Pin.PWRIN,do_erc=True),
            Pin(num='C9',name='TCVSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D9',name='RG',func=Pin.OUTPUT,do_erc=True),
            Pin(num='E9',name='RGVSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='H4',func=Pin.OUTPUT,do_erc=True),
            Pin(num='G9',name='HVSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H9',name='H2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='J9',name='VSG6',func=Pin.OUTPUT,do_erc=True),
            Pin(num='K9',name='VSG5',func=Pin.OUTPUT,do_erc=True),
            Pin(num='A10',name='AVDD1',func=Pin.PWRIN,do_erc=True),
            Pin(num='B10',name='TCVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C10',name='CLI',do_erc=True),
            Pin(num='D10',name='CLO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='E10',name='RGVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='H3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='G10',name='HVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='H1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='J10',name='VSG8',func=Pin.OUTPUT,do_erc=True),
            Pin(num='K10',name='VSG7',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='AD9895',dest=TEMPLATE,tool=SKIDL,keywords='CCD Signal Processor',description='CCD Signal Processor, 30MHz 12bits, CSPBGA-64',ref_prefix='U',num_units=1,fplist=['BGA*10x10*9.0x9.0mm*Pitch0.8mm*'],do_erc=True,pins=[
            Pin(num='A1',name='VD',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='HD',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='SYNC',do_erc=True),
            Pin(num='D1',name='DCLK',func=Pin.OUTPUT,do_erc=True),
            Pin(num='E1',name='D1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='F1',name='D3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='G1',name='D5',func=Pin.OUTPUT,do_erc=True),
            Pin(num='H1',name='D7',func=Pin.OUTPUT,do_erc=True),
            Pin(num='J1',name='D9',func=Pin.OUTPUT,do_erc=True),
            Pin(num='K1',name='D11',do_erc=True),
            Pin(num='A2',name='DVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='B2',name='DVSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='LD/FD',func=Pin.OUTPUT,do_erc=True),
            Pin(num='D2',name='PBLK/CLPOB',func=Pin.OUTPUT,do_erc=True),
            Pin(num='E2',name='D0',func=Pin.OUTPUT,do_erc=True),
            Pin(num='F2',name='D2/SD0',func=Pin.OUTPUT,do_erc=True),
            Pin(num='G2',name='D4',func=Pin.OUTPUT,do_erc=True),
            Pin(num='H2',name='D6',func=Pin.OUTPUT,do_erc=True),
            Pin(num='J2',name='D8',func=Pin.OUTPUT,do_erc=True),
            Pin(num='K2',name='D10',func=Pin.OUTPUT,do_erc=True),
            Pin(num='A3',name='MSHUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='B3',name='STROBE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='J3',name='VSUB',func=Pin.OUTPUT,do_erc=True),
            Pin(num='K3',name='DRVDD',func=Pin.PWROUT,do_erc=True),
            Pin(num='A4',name='SDI',do_erc=True),
            Pin(num='B4',name='SCK',do_erc=True),
            Pin(num='J4',name='SUBCK',func=Pin.OUTPUT,do_erc=True),
            Pin(num='K4',name='DRVSS',func=Pin.PWROUT,do_erc=True),
            Pin(num='A5',name='REFT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='B5',name='SL',do_erc=True),
            Pin(num='J5',name='V2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='K5',name='V1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='A6',name='REFB',func=Pin.OUTPUT,do_erc=True),
            Pin(num='B6',name='AVSS2',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='V4',func=Pin.OUTPUT,do_erc=True),
            Pin(num='K6',name='V3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='A7',name='BYP3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='B7',name='AVDD2',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VSG2/V6',func=Pin.OUTPUT,do_erc=True),
            Pin(num='K7',name='VSG1/V5',func=Pin.OUTPUT,do_erc=True),
            Pin(num='A8',name='CDD-IN',do_erc=True),
            Pin(num='B8',name='BYP2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='J8',name='VSG4/V8',func=Pin.OUTPUT,do_erc=True),
            Pin(num='K8',name='VSG3/V7',func=Pin.OUTPUT,do_erc=True),
            Pin(num='A9',name='BYP1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='B9',name='AVSS1',func=Pin.PWRIN,do_erc=True),
            Pin(num='C9',name='TCVSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D9',name='RG',func=Pin.OUTPUT,do_erc=True),
            Pin(num='E9',name='RGVSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='H4',func=Pin.OUTPUT,do_erc=True),
            Pin(num='G9',name='HVSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H9',name='H2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='J9',name='VSG6',func=Pin.OUTPUT,do_erc=True),
            Pin(num='K9',name='VSG5',func=Pin.OUTPUT,do_erc=True),
            Pin(num='A10',name='AVDD1',func=Pin.PWRIN,do_erc=True),
            Pin(num='B10',name='TCVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C10',name='CLI',do_erc=True),
            Pin(num='D10',name='CLO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='E10',name='RGVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='H3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='G10',name='HVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='H1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='J10',name='VSG8',func=Pin.OUTPUT,do_erc=True),
            Pin(num='K10',name='VSG7',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='AV9173',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='CX7930',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='CXD3400N',dest=TEMPLATE,tool=SKIDL,keywords='CCD Clock Driver',description='6-channel Vertical Clock Driver for CCD Image Sensor, SSOP-20',ref_prefix='U',num_units=1,fplist=['SSOP*'],do_erc=True,pins=[
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='XSHT',do_erc=True),
            Pin(num='3',name='XV3',do_erc=True),
            Pin(num='4',name='XSG3B',do_erc=True),
            Pin(num='5',name='XSG3A',do_erc=True),
            Pin(num='6',name='XV1',do_erc=True),
            Pin(num='7',name='XSG1B',do_erc=True),
            Pin(num='8',name='XSG1A',do_erc=True),
            Pin(num='9',name='XV4',do_erc=True),
            Pin(num='10',name='XV2',do_erc=True),
            Pin(num='20',name='SHT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='11',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='V2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='V4',func=Pin.OUTPUT,do_erc=True),
            Pin(num='14',name='V1A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='15',name='VH',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='V1B',func=Pin.OUTPUT,do_erc=True),
            Pin(num='17',name='V3A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='18',name='VL',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='V3B',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='HD63484',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='HD63484_PLCC',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='ICX415AQ',dest=TEMPLATE,tool=SKIDL,keywords='CCD B/W Image Sensor',description='Diagonal 8mm B/W Progressive Scan CCD Image Sensor with Square Pixel, CERDIP-22',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='3',name='V3',do_erc=True),
            Pin(num='4',name='V2',do_erc=True),
            Pin(num='5',name='V1',do_erc=True),
            Pin(num='7',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VOUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='10',name='CGG',do_erc=True),
            Pin(num='20',name='CSUB',do_erc=True),
            Pin(num='21',name='SUBCIR',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='RG',do_erc=True),
            Pin(num='14',name='VL',func=Pin.PWRIN,do_erc=True),
            Pin(num='15',name='SUB',do_erc=True),
            Pin(num='16',name='H1',do_erc=True),
            Pin(num='17',name='H2',do_erc=True)]),
        Part(name='LM1881',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='MAX310',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='MAX311',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='MB88303P',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='S178',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='SI582',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='TDA1950',dest=TEMPLATE,tool=SKIDL,do_erc=True,aliases=['TDA1950F']),
        Part(name='TDA2593',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='TDA7260',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='TDA9500',dest=TEMPLATE,tool=SKIDL,do_erc=True,aliases=['TDA9503', 'TDA9513']),
        Part(name='TEA5115',dest=TEMPLATE,tool=SKIDL,do_erc=True)])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

motor_drivers = SchLib(tool=SKIDL).add_parts(*[
        Part(name='A4950E',dest=TEMPLATE,tool=SKIDL,keywords='full-bridge h-bridge',description='Full-Bridge, DMOS PWM, Motor Driver, 40V, 3.5A, -40 to +125C',ref_prefix='U',num_units=1,fplist=['SOIC-*1EP*'],do_erc=True,aliases=['A4950K'],pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='IN2',do_erc=True),
            Pin(num='3',name='IN1',do_erc=True),
            Pin(num='4',name='VREF',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='VBB',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='OUT1',func=Pin.PWROUT,do_erc=True),
            Pin(num='7',name='LSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='OUT2',func=Pin.PWROUT,do_erc=True),
            Pin(num='9',name='PAD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='DRV8308',dest=TEMPLATE,tool=SKIDL,keywords='bldc mosfet-driver hall-sensor',description='Brushless DC motor controller, closed loop, hall sensor inputs, current limiting, SPI interface',ref_prefix='U',num_units=1,fplist=['QFN*1EP*6x6mm*Pitch0.5mm*'],do_erc=True,pins=[
            Pin(num='1',name='UHP',do_erc=True),
            Pin(num='2',name='UHN',do_erc=True),
            Pin(num='3',name='VHP',do_erc=True),
            Pin(num='4',name='VHN',do_erc=True),
            Pin(num='5',name='WHP',do_erc=True),
            Pin(num='6',name='WHN',do_erc=True),
            Pin(num='7',name='VSW',func=Pin.PWROUT,do_erc=True),
            Pin(num='8',name='FGFB',func=Pin.OUTPUT,do_erc=True),
            Pin(num='9',name='FGINN_TACH',do_erc=True),
            Pin(num='10',name='FGINP',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='BRAKE',do_erc=True),
            Pin(num='30',name='CP1',func=Pin.PASSIVE,do_erc=True),
            Pin(num='40',name='WLSG',func=Pin.OUTPUT,do_erc=True),
            Pin(num='11',name='SCLK',do_erc=True),
            Pin(num='21',name='DIR',do_erc=True),
            Pin(num='31',name='ISEN',do_erc=True),
            Pin(num='41',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='SCS',do_erc=True),
            Pin(num='22',name='ENABLE',do_erc=True),
            Pin(num='32',name='UHSG',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='SMODE',do_erc=True),
            Pin(num='23',name='RESET',do_erc=True),
            Pin(num='33',name='U',do_erc=True),
            Pin(num='14',name='SDATAI',do_erc=True),
            Pin(num='24',name='VREG',func=Pin.PWROUT,do_erc=True),
            Pin(num='34',name='ULSG',func=Pin.OUTPUT,do_erc=True),
            Pin(num='15',name='SDATAO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='25',name='VINT',func=Pin.PASSIVE,do_erc=True),
            Pin(num='35',name='VHSG',func=Pin.OUTPUT,do_erc=True),
            Pin(num='16',name='FGOUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='26',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='V',do_erc=True),
            Pin(num='17',name='~FAULTn',func=Pin.OUTPUT,do_erc=True),
            Pin(num='27',name='VM',func=Pin.PWRIN,do_erc=True),
            Pin(num='37',name='VLSG',func=Pin.OUTPUT,do_erc=True),
            Pin(num='18',name='~LOCKn',func=Pin.OUTPUT,do_erc=True),
            Pin(num='28',name='VCP',func=Pin.PASSIVE,do_erc=True),
            Pin(num='38',name='WHSG',func=Pin.OUTPUT,do_erc=True),
            Pin(num='19',name='CLKIN',do_erc=True),
            Pin(num='29',name='CP2',func=Pin.PASSIVE,do_erc=True),
            Pin(num='39',name='W',do_erc=True)]),
        Part(name='DRV8711',dest=TEMPLATE,tool=SKIDL,keywords='Stepper driver',description='Stepper motor controller, external N-channel MOSFET, single bipolar stepper motor, dual brushed DC motors',ref_prefix='U',num_units=1,fplist=['HTSSOP-38'],do_erc=True,pins=[
            Pin(num='1',name='CP1',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='CP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='VCP',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='VM',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='V5',func=Pin.PWROUT,do_erc=True),
            Pin(num='7',name='VINT',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='SLEEPn',do_erc=True),
            Pin(num='9',name='RESET',do_erc=True),
            Pin(num='10',name='STEP/AIN1',do_erc=True),
            Pin(num='20',name='BEMF',func=Pin.OUTPUT,do_erc=True),
            Pin(num='30',name='AOUT2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='11',name='DIR/AIN2',do_erc=True),
            Pin(num='21',name='BOUT2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='31',name='A2HS',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='BIN1',do_erc=True),
            Pin(num='22',name='B2HS',func=Pin.OUTPUT,do_erc=True),
            Pin(num='32',name='A2LS',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='BIN2',do_erc=True),
            Pin(num='23',name='B2LS',func=Pin.OUTPUT,do_erc=True),
            Pin(num='33',name='AISENN',do_erc=True),
            Pin(num='14',name='SCLK',do_erc=True),
            Pin(num='24',name='BISENN',do_erc=True),
            Pin(num='34',name='AISENP',do_erc=True),
            Pin(num='15',name='SDATI',do_erc=True),
            Pin(num='25',name='BISENP',do_erc=True),
            Pin(num='35',name='A1LS',func=Pin.OUTPUT,do_erc=True),
            Pin(num='16',name='SCS',do_erc=True),
            Pin(num='26',name='B1LS',func=Pin.OUTPUT,do_erc=True),
            Pin(num='36',name='A1HS',func=Pin.OUTPUT,do_erc=True),
            Pin(num='17',name='SDATO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='27',name='B1HS',func=Pin.OUTPUT,do_erc=True),
            Pin(num='37',name='AOUT1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='18',name='FAULTn',func=Pin.OUTPUT,do_erc=True),
            Pin(num='28',name='BOUT1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='38',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='STALLn/BEMFVn',func=Pin.OUTPUT,do_erc=True),
            Pin(num='29',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='L293',dest=TEMPLATE,tool=SKIDL,keywords='Half-H Driver Motor',description='Quadruple Half-H Drivers',ref_prefix='U',num_units=1,fplist=['DIP*W7.62mm*'],do_erc=True,aliases=['L293D'],pins=[
            Pin(num='1',name='EN1,2',do_erc=True),
            Pin(num='2',name='1A',do_erc=True),
            Pin(num='3',name='1Y',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='2Y',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='2A',do_erc=True),
            Pin(num='8',name='VCC2',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='EN3,4',do_erc=True),
            Pin(num='10',name='3A',do_erc=True),
            Pin(num='11',name='3A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='4Y',func=Pin.OUTPUT,do_erc=True),
            Pin(num='15',name='4A',do_erc=True),
            Pin(num='16',name='VCC1',func=Pin.PWRIN,do_erc=True)]),
        Part(name='L298(H)N',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='L298P',dest=TEMPLATE,tool=SKIDL,keywords='H-bridge motor driver',description='Dual full bridge motor driver, up to 46V, 4A',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='SENSE_A',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='4',name='OUT1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='OUT2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='Vs',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='IN1',do_erc=True),
            Pin(num='8',name='EnA',do_erc=True),
            Pin(num='9',name='IN2',do_erc=True),
            Pin(num='10',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='Vss',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='IN3',do_erc=True),
            Pin(num='14',name='EnB',do_erc=True),
            Pin(num='15',name='IN4',do_erc=True),
            Pin(num='16',name='OUT3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='17',name='OUT4',func=Pin.OUTPUT,do_erc=True),
            Pin(num='18',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='19',name='SENSE_B',func=Pin.PWRIN,do_erc=True)]),
        Part(name='PG001M',dest=TEMPLATE,tool=SKIDL,keywords='Support IC for SLA7042M/SLA7044M',description='Parallel to serial data converter for SLA7042M/SLA7044M',ref_prefix='U',num_units=1,fplist=['DIP*', 'PDIP*'],do_erc=True,pins=[
            Pin(num='1',name='~RESET~',do_erc=True),
            Pin(num='2',name='CLK_IN',do_erc=True),
            Pin(num='3',name='~CW~',do_erc=True),
            Pin(num='6',name='MSEL_1',do_erc=True),
            Pin(num='7',name='MSEL_2',do_erc=True),
            Pin(num='8',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='~MONITOR~',do_erc=True),
            Pin(num='10',name='DATA_B',func=Pin.OUTPUT,do_erc=True),
            Pin(num='11',name='DATA_A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='~STROBE~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='14',name='CLK_OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='15',name='VECTOR',do_erc=True),
            Pin(num='16',name='Vdd',func=Pin.PWRIN,do_erc=True)]),
        Part(name='SLA7044M',dest=TEMPLATE,tool=SKIDL,keywords='Stepper driver',description='Unipolar PWM high-current motor driver',ref_prefix='U',num_units=2,fplist=['SLA704XM'],do_erc=True,aliases=['SLA7042M'],pins=[
            Pin(num='1',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='~STROBE~',do_erc=True),
            Pin(num='3',name='REF',do_erc=True),
            Pin(num='4',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='~CLOCK~',do_erc=True),
            Pin(num='6',name='DATA',do_erc=True),
            Pin(num='7',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='~OUT~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='9',name='RS',do_erc=True),
            Pin(num='10',name='RS',do_erc=True),
            Pin(num='11',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='~STROBE~',do_erc=True),
            Pin(num='14',name='REF',do_erc=True),
            Pin(num='15',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='~CLOCK~',do_erc=True),
            Pin(num='17',name='DATA',do_erc=True),
            Pin(num='18',name='~OUT~',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='SLA7070MPRT',dest=TEMPLATE,tool=SKIDL,keywords='Stepper driver',description='Unipolar 2-phase stepper motor driver, Full and Half step, 3A',ref_prefix='U',num_units=1,fplist=['ZIP23'],do_erc=True,aliases=['SLA7071MPRT', 'SLA7072MPRT', 'SLA7073MPRT'],pins=[
            Pin(num='1',name='OUTA',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='OUTA',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='~OUTA~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='~OUTA~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='SENSE_A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='N.C.',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='7',name='M1',do_erc=True),
            Pin(num='8',name='M2',do_erc=True),
            Pin(num='9',name='M3',do_erc=True),
            Pin(num='10',name='CLOCK',do_erc=True),
            Pin(num='20',name='~OUTB~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='11',name='VBB',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='~OUTB~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='OUTB',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='REF/SLEEP1',do_erc=True),
            Pin(num='23',name='OUTB',func=Pin.OUTPUT,do_erc=True),
            Pin(num='14',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='15',name='RESET',do_erc=True),
            Pin(num='16',name='CW/CCW',do_erc=True),
            Pin(num='17',name='SYNC',do_erc=True),
            Pin(num='18',name='FLAG',func=Pin.OUTPUT,do_erc=True),
            Pin(num='19',name='SENSE_B',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='SLA7075MPRT',dest=TEMPLATE,tool=SKIDL,keywords='Stepper driver',description='Unipolar 2-phase stepper motor driver, Microstep, 3A',ref_prefix='U',num_units=1,fplist=['ZIP23'],do_erc=True,aliases=['SLA7076MPRT', 'SLA7077MPRT', 'SLA7078MPRT'],pins=[
            Pin(num='1',name='OUTA',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='OUTA',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='~OUTA~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='~OUTA~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='SENSE_A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='MO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='M1',do_erc=True),
            Pin(num='8',name='M2',do_erc=True),
            Pin(num='9',name='M3',do_erc=True),
            Pin(num='10',name='CLOCK',do_erc=True),
            Pin(num='20',name='~OUTB~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='11',name='VBB',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='~OUTB~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='OUTB',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='REF/SLEEP1',do_erc=True),
            Pin(num='23',name='OUTB',func=Pin.OUTPUT,do_erc=True),
            Pin(num='14',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='15',name='RESET',do_erc=True),
            Pin(num='16',name='CW/CCW',do_erc=True),
            Pin(num='17',name='SYNC',do_erc=True),
            Pin(num='18',name='FLAG',func=Pin.OUTPUT,do_erc=True),
            Pin(num='19',name='SENSE_B',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='STK672-040-E',dest=TEMPLATE,tool=SKIDL,keywords='Stepper driver',description='Stepper motor driver with microstepping controller, 1.5A',ref_prefix='U',num_units=1,fplist=['STK672-040-E'],do_erc=True,pins=[
            Pin(num='1',name='~B~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='B',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='PG',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='PG',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='~A~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='Vref',do_erc=True),
            Pin(num='9',name='M1',do_erc=True),
            Pin(num='10',name='M2',do_erc=True),
            Pin(num='20',name='MO1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='11',name='M3',do_erc=True),
            Pin(num='21',name='MO2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='M4',do_erc=True),
            Pin(num='22',name='SG',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='M5',do_erc=True),
            Pin(num='14',name='CLK',do_erc=True),
            Pin(num='15',name='CWB',do_erc=True),
            Pin(num='16',name='~RESET~',do_erc=True),
            Pin(num='17',name='RETURN',do_erc=True),
            Pin(num='18',name='ENABLE',do_erc=True),
            Pin(num='19',name='MOI',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='STK672-080-E',dest=TEMPLATE,tool=SKIDL,keywords='Stepper driver',description='Stepper motor driver with microstepping controller, 2.8A',ref_prefix='U',num_units=1,fplist=['STK672-080-E'],do_erc=True,pins=[
            Pin(num='1',name='PG',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='BB',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='B',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='AB',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='Vref',do_erc=True),
            Pin(num='8',name='M1',do_erc=True),
            Pin(num='9',name='M2',do_erc=True),
            Pin(num='10',name='CWB',do_erc=True),
            Pin(num='11',name='CLOCK',do_erc=True),
            Pin(num='12',name='M3',do_erc=True),
            Pin(num='13',name='~RESET~',do_erc=True),
            Pin(num='14',name='MOI',func=Pin.OUTPUT,do_erc=True),
            Pin(num='15',name='ENABLE',do_erc=True)]),
        Part(name='STSPIN220',dest=TEMPLATE,tool=SKIDL,keywords='motor driver stepper',description='Low voltage stepper motor driver, 1.8V to 10V input, 1.3Arms output, 0.4Ω Rdson per phase (typical), QFN-16 package',ref_prefix='U',num_units=1,fplist=['QFN*3x3mm*Pitch0.5mm*'],do_erc=True,pins=[
            Pin(num='1',name='DIR',do_erc=True),
            Pin(num='2',name='STCK',do_erc=True),
            Pin(num='3',name='OUTA1',func=Pin.PWROUT,do_erc=True),
            Pin(num='4',name='SENSEA',func=Pin.PWROUT,do_erc=True),
            Pin(num='5',name='OUTA2',func=Pin.PWROUT,do_erc=True),
            Pin(num='6',name='VS',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='OUTB2',func=Pin.PWROUT,do_erc=True),
            Pin(num='9',name='SENSEB',func=Pin.PWROUT,do_erc=True),
            Pin(num='10',name='OUTB1',func=Pin.PWROUT,do_erc=True),
            Pin(num='11',name='REF',do_erc=True),
            Pin(num='12',name='TOFF',do_erc=True),
            Pin(num='13',name='EN/FLT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='STBY/RESET',do_erc=True),
            Pin(num='15',name='MODE2',do_erc=True),
            Pin(num='16',name='MODE1',do_erc=True),
            Pin(num='17',name='EPAD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STSPIN230',dest=TEMPLATE,tool=SKIDL,keywords='motor driver half-bridge',description='Low voltage triple half-bridge motor driver, 1.8V to 10V input, 1.3Arms output, 0.4Ω Rdson per phase (typical), QFN-16 package',ref_prefix='U',num_units=1,fplist=['QFN*3x3mm*Pitch0.5mm*'],do_erc=True,pins=[
            Pin(num='1',name='INUH',do_erc=True),
            Pin(num='2',name='INUL',do_erc=True),
            Pin(num='3',name='OUTU',func=Pin.PWROUT,do_erc=True),
            Pin(num='4',name='SENSE',do_erc=True),
            Pin(num='5',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='6',name='VS',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='OUTV',func=Pin.PWROUT,do_erc=True),
            Pin(num='9',name='SENSE',do_erc=True),
            Pin(num='10',name='OUTW',func=Pin.PWROUT,do_erc=True),
            Pin(num='11',name='INWL',do_erc=True),
            Pin(num='12',name='INWH',do_erc=True),
            Pin(num='13',name='EN/FLT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='STBY',do_erc=True),
            Pin(num='15',name='INVL',do_erc=True),
            Pin(num='16',name='INVH',do_erc=True),
            Pin(num='17',name='PAD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STSPIN240',dest=TEMPLATE,tool=SKIDL,keywords='motor driver dc brushed',description='Low voltage dual brush DC motor driver, 1.8V to 10V input, 1.3Arms output, 0.4Ω Rdson per phase (typical), QFN-16 package',ref_prefix='U',num_units=1,fplist=['QFN*3x3mm*Pitch0.5mm*'],do_erc=True,pins=[
            Pin(num='1',name='PHA',do_erc=True),
            Pin(num='2',name='PWMA',do_erc=True),
            Pin(num='3',name='OUTA1',func=Pin.PWROUT,do_erc=True),
            Pin(num='4',name='SENSEA',func=Pin.PWROUT,do_erc=True),
            Pin(num='5',name='OUTA2',func=Pin.PWROUT,do_erc=True),
            Pin(num='6',name='VS',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='OUTB2',func=Pin.PWROUT,do_erc=True),
            Pin(num='9',name='SENSEB',func=Pin.PWROUT,do_erc=True),
            Pin(num='10',name='OUTB1',func=Pin.PWROUT,do_erc=True),
            Pin(num='11',name='REF',do_erc=True),
            Pin(num='12',name='TOFF',do_erc=True),
            Pin(num='13',name='EN/FLT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='STBY/RESET',do_erc=True),
            Pin(num='15',name='PHB',do_erc=True),
            Pin(num='16',name='PWMB',do_erc=True),
            Pin(num='17',name='EPAD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='TMC262',dest=TEMPLATE,tool=SKIDL,keywords='trinamic tlc262 stepper',description='Driver for two-phase stepper motors with external mosfet',ref_prefix='U',num_units=1,fplist=['QFN*1EP*5x5mm*Pitch0.5mm*'],do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='HA1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='HA2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='BMA2',do_erc=True),
            Pin(num='5',name='BMA1',do_erc=True),
            Pin(num='6',name='LA1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='LA2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='SRA',do_erc=True),
            Pin(num='9',name='5VOUT',func=Pin.PWROUT,do_erc=True),
            Pin(num='10',name='SD0',func=Pin.TRISTATE,do_erc=True),
            Pin(num='20',name='BMB1',do_erc=True),
            Pin(num='30',name='DIR',do_erc=True),
            Pin(num='11',name='SDI',do_erc=True),
            Pin(num='21',name='BMB2',do_erc=True),
            Pin(num='31',name='STEP',do_erc=True),
            Pin(num='12',name='SCK',do_erc=True),
            Pin(num='22',name='HB2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='32',name='TST_MODE',do_erc=True),
            Pin(num='13',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='HB1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='33',name='DIE_PAD',do_erc=True),
            Pin(num='14',name='CSN',do_erc=True),
            Pin(num='24',name='VHS',func=Pin.PWRIN,do_erc=True),
            Pin(num='15',name='~ENN~',do_erc=True),
            Pin(num='25',name='VS',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='CLK',do_erc=True),
            Pin(num='26',name='TST_ANA',func=Pin.OUTPUT,do_erc=True),
            Pin(num='17',name='SRB',do_erc=True),
            Pin(num='27',name='SG_TST',func=Pin.OUTPUT,do_erc=True),
            Pin(num='18',name='LB2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='28',name='GNDP',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='LB1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='29',name='VCC_IO',func=Pin.PWRIN,do_erc=True)])])


from skidl import *

# Libraries.
xess_lib = r'C:\xesscorp\KiCad\libraries\xess.lib'
pic32_lib = r'C:\xesscorp\KiCad\libraries\pic32.lib'
pickit3_lib = r'C:\xesscorp\KiCad\libraries\pickit3.lib'

# Global nets.
gnd = Net('GND')
gnd.drive = POWER
vusb = Net('VUSB')
vusb.drive = POWER
vdd = Net('+3.3V')

# Some common parts used as templates.
cap = Part('device', 'C', footprint='Capacitors_SMD:C_0603', dest=TEMPLATE)
res = Part('device', 'R', footprint='Resistors_SMD:R_0603', dest=TEMPLATE)

# Regulate +5V VUSB down to +3.3V for VDD.
vreg = Part(xess_lib, 'TPS793XX', footprint='TO_SOT_Packages_SMD:SOT-23-5')
noise_cap = cap(value='0.01uf')
vreg['IN, EN'] += vusb
vreg['GND'] += gnd
vreg['OUT'] += vdd
vreg['NR'] += noise_cap[1]
noise_cap[2] += gnd

# Microcontroller.
pic32 = Part(pic32_lib, 'pic32MX2\*0F\*\*\*B-QFN28',
             footprint='Housings_DFN_QFN:QFN-28-1EP_6x6mm_Pitch0.65mm')
pic32['VSS'] += gnd
pic32['VDD'] += vdd  # Main CPU power.
pic32['VUSB3V3'] += vdd  # Power to USB transceiver.
pic32['^VBUS$'] += vusb  # Monitor power pin of USB connector.
pic32['PAD'] += gnd  # Power pad on bottom attached to ground.

# Bypass capacitors for microcontroller.
bypass = cap(3, value='0.1uf')
bypass[0][1, 2] += vdd, gnd
bypass[1][1, 2] += vdd, gnd
bypass[2][1, 2] += pic32['VCAP'], gnd

# Microcontroller MCLR circuitry:
#   Pull-up resistor to VDD.
#   Filter capacitor to delay exit of reset or eliminate glitches.
#   Series resistor to isolate capacitor from device programmer.
r_pullup = res(value='10K')
r_series = res(value='1K')
filter_cap = cap(value='0.1uf')
r_series[1, 2] += r_pullup[1], pic32['MCLR']
r_pullup[2] += vdd
filter_cap[1, 2] += r_series[1], gnd

# USB connector.
usb_conn = Part(xess_lib, 'USB-MicroB', footprint='XESS:USB-microB-1')
usb_conn['D\+, D-, VBUS, GND, NC'] += pic32['D\+, D-'], vusb, gnd, NC
# Noise filtering/isolation on the USB connector shield.
shld_cap = cap(value='4.7nf')
shld_res = res(value='1M')
shld_cap[1] += usb_conn['shield']
shld_res[1] += usb_conn['shield']
gnd += shld_cap[2], shld_res[2]

# LED with current-limiting resistor driven by microcontroller pin.
led = Part('device', 'led', footprint='Diodes_SMD:D_0603')
led_curr_limit = res(value='1K')
led_curr_limit[1, 2] += pic32['RB4'], led['A']
led['K'] += gnd

# Crystal and trim capacitors.
xtal = Part(xess_lib, 'XTAL4', footprint='XESS:32x25-4')
xtal[2, 4] += gnd
pic32['OSC1, OSC2'] += xtal[3, 1]
trim_cap = cap(2, value='10pf')
trim_cap[0][1, 2] += xtal[1], gnd
trim_cap[1][1, 2] += xtal[3], gnd

# Port for attachment of device programmer.
prg_hdr = Part(pickit3_lib, 'pickit3_hdr', footprint='Pin_Headers:Pin_Header_Straight_1x06')
prg_hdr.ref = 'PRG'
prg_hdr['MCLR'] += pic32['MCLR']
prg_hdr['VDD'] += vdd
prg_hdr['GND'] += gnd
prg_hdr['PGC'] += pic32['PGEC1']
prg_hdr['PGD'] += pic32['PGED1']

# Port for attachment of FPGA programming pins.
port = Part('conn', 'CONN_01x06', footprint='Pin_Headers:Pin_Header_Straight_1x06')
port.ref = 'JTAG'
port[1, 2] += vusb, gnd
port[3] += pic32['SCK1'] # SCK1 output.
port[5] += pic32['RB5']  # PPS: SDI1 input.
port[4] += pic32['RB15'] # PPS: SS1 output.
port[6] += pic32['RA4']  # PPS: SDO1 output.

ERC()
generate_netlist()



# -*- coding: utf-8 -*-

# MIT license
#
# Copyright (C) 2018 by XESS Corp.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
"""
Handler for reading SPICE libraries.
"""

from __future__ import unicode_literals
from __future__ import print_function
from __future__ import division
from __future__ import absolute_import

from builtins import str
from builtins import int
from builtins import range
from builtins import dict
from builtins import zip
from future import standard_library
standard_library.install_aliases()

import os.path
from ..py_2_3 import *
from ..defines import *
from ..utilities import *
from ..Part import Part
from ..Net import Net
from ..Pin import Pin

# PySpice may not be installed, particularly under Python 2.
try:
    from PySpice.Spice.Library import SpiceLibrary
    from PySpice.Spice.Netlist import Circuit as PySpiceCircuit # Avoid clash with Circuit class below.
except ImportError:
    pass

tool_name = SPICE
lib_suffix = '.lib'


def _load_sch_lib_(self, filename=None, lib_search_paths_=None):
    """
    Load the .subckt I/O from a SPICE library file.

    Args:
        filename: The name of the SPICE library file.
        lib_search_paths_ : List of directories to search for the file.
    """

    from ..skidl import lib_suffixes
    from ..Part import Part
    from ..Pin import Pin

    # Try to open the file. Add a .lib extension if needed. If the file
    # doesn't open, then try looking in the KiCad library directory.
    try:
        f, filepath = find_and_open_file(
            filename,
            lib_search_paths_,
            lib_suffixes[SPICE],
            allow_failure=False,
            exclude_binary=True,
            descend=-1)
    except Exception as e:
        raise Exception('Unable to open SPICE Library File {} ({})'.format(
            filename, str(e)))

    # Read the definition of each part line-by-line and then create
    # a Part object that gets stored in the part list.
    for line in f:

        # Skip over comments.
        if line.startswith('*'):
            pass

        # Look for the start of a part definition.
        elif line.lower().startswith('.subckt'):
            # Part definition is the 1st line plus any continuation lines.
            while line.endswith('+'):
                line = line[:-1]  # Remove '+' at end of current line.
                line += ' ' + f.readline()  # Append the next line.

            # Create the part with the part definition.
            part = _mk_subckt_part(line)  # Create un-filled part template.

            # Flesh-out the part.
            part.filename = filepath  # Store filename where this part came from.

            # Parse the part definition.
            pieces = part.part_defn.split()
            try:
                # part defn: .subckt part_name pin1, pin2, ... pinN.
                part.name = pieces[1]
                part.pins = [Pin(num=p, name=p) for p in pieces[2:]]
                part.associate_pins()
            except IndexError:
                logger.warn('Misformatted SPICE subcircuit: {}'.format(
                    part.part_defn))
            else:
                # Now find a symbol file for the part to assign names to the pins.
                # First, check for LTSpice symbol file.
                sym_file, _ = find_and_open_file(
                    part.name, lib_search_paths_, '.asy',
                    allow_failure=True, exclude_binary=True, descend=-1)
                if sym_file:
                    pin_names = []
                    pin_indices = []
                    for sym_line in sym_file:
                        if sym_line.lower().startswith('pinattr pinname'):
                            pin_names.append(sym_line.split()[2])
                        elif sym_line.lower().startswith('pinattr spiceorder'):
                            pin_indices.append(sym_line.split()[2])
                        elif sym_line.lower().startswith(
                                'symattr description'):
                            part.description = ' '.join(sym_line.split()[2:])
                    # Pin names and indices should be matched by the order they
                    # appeared in the symbol file. Each index should match the
                    # order of the pins in the .subckt file.
                    for index, name in zip(pin_indices, pin_names):
                        part.pins[int(index) - 1].name = name
                else:
                    # No LTSpice symbol file, so check for PSPICE symbol file.
                    sym_file, diag = find_and_open_file(
                        filename, lib_search_paths_, '.slb',
                        allow_failure=True, exclude_binary=True, descend=-1)
                    if sym_file:
                        pin_names = []
                        active = False
                        for sym_line in sym_file:
                            line_parts = sym_line.lower().split()
                            if line_parts[0] == '*symbol':
                                active = (line_parts[1]==part.name.lower())
                            if active:
                                if line_parts[0] == 'p':
                                    pin_names.append(line_parts[6])
                                elif line_parts[0] == 'd':
                                    part.description = ' '.join(line_parts[1:])
                        pin_indices = list(range(len(pin_names)))
                        for pin, name in zip(part.pins, pin_names):
                            pin.name = name

            # Remove the part definition string since we're done parsing it.
            self.part_defn = None

            self.add_parts(part)

def _parse_lib_part_(self, just_get_name=False):  # pylint: disable=unused-argument
    """
    Create a Part using a part definition from a SPICE library.
    """

    # Parts in a SPICE library are already parsed and ready for use,
    # so just return the part.
    return self


def _mk_subckt_part(defn='XXX'):
    part = Part(part_defn=defn, tool=SPICE, dest=LIBRARY)
    part.part_defn = defn
    part.fplist = []
    part.aliases = []
    part.num_units = 1
    part.ref_prefix = 'X'
    part._ref = None
    part.filename = ''
    part.name = ''
    part.pins = []
    part.pyspice = {'name': 'X', 'add': add_subcircuit_to_circuit}
    return part

def _gen_netlist_(self, **kwargs):
    """
    Return a PySpice Circuit generated from a SKiDL circuit.

    Args:
        title: String containing the title for the PySpice circuit.
        libs: String or list of strings containing the paths to directories
            containing SPICE models.
    """

    if USING_PYTHON2:
        return None

    # Create an empty PySpice circuit.
    title = kwargs.pop('title', '') # Get title and remove it from kwargs.
    circuit = PySpiceCircuit(title)

    # Initialize set of libraries to include in the PySpice circuit.
    includes = set()

    # Add any models used by the parts.
    models = set([getattr(part, 'model', None) for part in self.parts])
    models.discard(None)
    lib_dirs = set(flatten([kwargs.get('libs', None)]))
    lib_dirs.discard(None)
    spice_libs = [SpiceLibrary(dir) for dir in lib_dirs]
    for model in models:
        for spice_lib in spice_libs:
            try:
                includes.add(spice_lib[model])
            except KeyError:
                pass
            else:
                break
        else:
            logger.error('Unknown SPICE model: {}'.format(model))

    # Add any subckt libraries used by the parts.
    part_names = set([getattr(part, 'name', None) for part in self.parts if getattr(part, 'filename', None)])
    lib_files = set([getattr(part, 'filename', None) for part in self.parts])
    lib_files.discard(None)
    lib_dirs = [os.path.dirname(f) for f in lib_files]
    spice_libs = [SpiceLibrary(dir) for dir in lib_dirs]
    for part_name in part_names:
        for spice_lib in spice_libs:
            try:
                includes.add(spice_lib[part_name])
            except KeyError:
                pass
            else:
                break
        else:
            logger.error('Unknown SPICE subckt: {}'.format(part_name))

    # Add the models and subckt libraries to the PySpice circuit.
    for inc in includes:
        circuit.include(inc)

    # Add each part in the SKiDL circuit to the PySpice circuit.
    for part in sorted(self.parts, key=lambda p: str(p.ref)):
        # Add each part. All PySpice parts have an add_to_spice attribute
        # and can be added directly. Other parts are added as subcircuits.
        try:
            add_func = part.pyspice['add']
        except (AttributeError, KeyError):
            logger.error('Part has no SPICE model: {}'.format(part))
        else:
            add_func(part, circuit)
                    
    return circuit


def node(net_or_pin):
    if isinstance(net_or_pin, Net):
        return net_or_pin.name
    if isinstance(net_or_pin, Pin):
        return net_or_pin.net.name


def _get_spice_ref(part):
    '''Return a SPICE reference ID for the part.'''
    if part.ref.startswith(part.ref_prefix):
        return part.ref[len(part.ref_prefix):]
    return part.ref


def _get_kwargs(part, kw):
    '''Return a dict of keyword arguments to PySpice element constructor.'''
    kwargs = {}

    for key, param_name in kw.items():
        try:
            # The key indicates some attribute of the part.
            part_attr = getattr(part, key)
        except AttributeError:
            pass
        else:
            # If the keyword argument is a Part, then substitute the part
            # reference because it's probably a control current for something
            # like a current-controlled source or switch.
            if isinstance(part_attr, Part):
                kwargs.update({param_name: part_attr.ref})
            # If the keyword argument is a Net, substitute the net name.
            elif isinstance(part_attr, Net):
                kwargs.update({param_name: node(part_attr)})
            # If the keyword argument is a Pin, skip it. It gets handled below.
            elif isinstance(part_attr, Pin):
                continue
            else:
                kwargs.update({param_name: part_attr})

    for pin in part.pins:
        if pin.is_connected():
            try:
                param_name = kw[pin.name]
                kwargs.update({param_name: node(pin)})
            except KeyError:
                logger.error('Part {}-{} has no {} pin: {}'.format(part.ref, part.name, pin.name, part))

    return kwargs


def add_part_to_circuit(part, circuit):
    '''
    Add a part to a PySpice Circuit object.

    Args:
        part: SKiDL Part object.
        circuit: PySpice Circuit object.
    '''

    kw = part.pyspice['kw']

    # Positional arguments start with the device name.
    args = [_get_spice_ref(part)]

    # Get keyword arguments.
    kwargs = _get_kwargs(part, kw)

    # Add the part to the PySpice circuit.
    getattr(circuit, part.pyspice['name'])(*args, **kwargs)


def _get_net_names(part):
    '''Return a list of net names attached to the pins of a part.'''
    return [node(pin) for pin in part.pins if pin.is_connected()]


def add_subcircuit_to_circuit(part, circuit):
    '''
    Add a .SUBCKT part to a PySpice Circuit object.

    Args:
        part: SKiDL Part object.
        circuit: PySpice Circuit object.
    '''

    args = [_get_spice_ref(part)]
    args.append(part.name)
    args.extend(_get_net_names(part))
    getattr(circuit, part.pyspice['name'])(*args)


def not_implemented(part, circuit):
    logger.error("Function not implemented for {} - {}.".format(
        part.name, part.ref))
